==> shelf_rest-0.1.4-pre.3.tar.gz: lib/src/hateoas_support.dart <==
// Copyright (c) 2014, The Shelf REST project authors.
// Please see the AUTHORS file for details.
// All rights reserved. Use of this source code is governed by
// a BSD 2-Clause License that can be found in the LICENSE file.

library shelf_rest.hateoas.support;

import 'package:uri/uri.dart';
import 'package:hateoas_models/hateoas_models.dart';
import 'resource.dart';
import 'package:path/path.dart' as path;

final p = path.url;



ResourceLinks generateLinks(Resource resource, resourceId) {
  final String pathValue = resourceId.toString();
  final self = Uri.parse(pathValue);
  final delete = resource.deleteRoute != null ? self : null;

  // TODO: We've lost the info about whether the put is an update or create
  // TODO: it could also be both???
//    final update = resource.putRoute != null  ? self : null;
  final update = null;

  final crs = resource.childResources;
  final childResourceLinks = {};
  crs.forEach((k, cr) {
    final childResourcePath = _relativise(k.toString());
    final prefix = p.join(pathValue, childResourcePath);
    final individualUrl = p.join(prefix, _relativise(cr.pathParamExpression));
    final searchUrl = prefix + _relativise(cr.searchPath);
    final search = cr.searchRoute != null ? new UriTemplate(searchUrl) : null;
    final find = cr.findRoute != null ? new UriTemplate(individualUrl) : null;
    // TODO: update vs create prob again
    final create = cr.postRoute != null ? Uri.parse(prefix) :
      cr.putRoute != null ? new UriTemplate(individualUrl) : null;
    final childUpdate = cr.putRoute != null ?
        new UriTemplate(individualUrl) : null;
    final childDelete = cr.deleteRoute != null ?
        new UriTemplate(individualUrl) : null;

    childResourceLinks[k] = new ChildResourceLinks.nullable(search, find,
        create, childUpdate, childDelete);
  });

  return new ResourceLinks.nullable(self, delete, update, childResourceLinks);
}

String _relativise(String path) {
  final r = p.isRelative(path) ? path : p.relative(path, from: p.separator);
  return r == '.' ? '' : r;
}

==> shelf_rest-0.1.5-pre.6.tar.gz: lib/src/hateoas_support.dart <==
// Copyright (c) 2014, The Shelf REST project authors.
// Please see the AUTHORS file for details.
// All rights reserved. Use of this source code is governed by
// a BSD 2-Clause License that can be found in the LICENSE file.

library shelf_rest.hateoas.support;

import 'package:uri/uri.dart';
import 'package:hateoas_models/hateoas_models.dart';
import 'resource.dart';
import 'package:path/path.dart' as path;

final p = path.url;

ResourceLinks generateLinks(Resource resource, resourceId) {
  final String pathValue = resourceId.toString();
  final self = Uri.parse(pathValue);
  final delete = resource.deleteRoute != null ? self : null;

  // TODO: We've lost the info about whether the put is an update or create
  // TODO: it could also be both???
//    final update = resource.putRoute != null  ? self : null;
  final update = null;

  final crs = resource.childResources;
  final childResourceLinks = {};
  crs.forEach((k, cr) {
    final childResourcePath = _relativise(k.toString());
    final prefix = p.join(pathValue, childResourcePath);
    final individualUrl = p.join(prefix, _relativise(cr.pathParamExpression));
    final searchUrl = cr.searchRoute != null ? prefix + _relativise(cr.searchRoute.queryParametersString) : null;
    final search = cr.searchRoute != null ? new UriTemplate(searchUrl) : null;
    final find = cr.findRoute != null ? new UriTemplate(individualUrl) : null;
    // TODO: update vs create prob again
    final UriTemplate create = cr.postRoute != null
        ? new UriTemplate(prefix)
        : cr.putRoute != null ? new UriTemplate(individualUrl) : null;

    // TODO: need to update hateoas models to make create a UriTemplate
    final createTempHack = create != null ? Uri.parse(create.expand({})) : null;
    final childUpdate =
        cr.putRoute != null ? new UriTemplate(individualUrl) : null;
    final childDelete =
        cr.deleteRoute != null ? new UriTemplate(individualUrl) : null;

    childResourceLinks[k] = new ChildResourceLinks.nullable(
        search, find, createTempHack, childUpdate, childDelete);
  });

  return new ResourceLinks.nullable(self, delete, update, childResourceLinks);
}

String _relativise(String path) {
  final r = p.isRelative(path) ? path : p.relative(path, from: p.separator);
  return r == '.' ? '' : r;
}
